/*
 * "Files"      File handling                                  Steve Chappell
 *
 * Updates
 *   27th Jun 97
 */

#include <stdio.h>
#include "files.h"

/*
 * Our version of fgets ignoring comments and blank lines 
 */
char *mygetline(char *buffer, int buflen, FILE *fp)
{
    char *p = buffer, *be = buffer + buflen;
    int c;
    do {
	while((c = getc(fp)) != EOF && c != '\n')
	{
	    if (c == '*' || c == '#' || c == '!')
	    {
		while((c = getc(fp)) != EOF && c != '\n')
		    ;
		break;
	    }
	    if (c != '\r' && p < be)
		*p++ = c;
	}
	*p = '\0';
	for(p = buffer; *p == ' ' || *p == '\t'; p++)
	    ;
    } while(*p == '\0' && c != EOF);

    if (*p != '\0')
	return(buffer);
    else
	*buffer = '\0';

    return(NULL);
}





